/*                                                                        */
/* Kinematics specification                                               */
/*                                                                        */
 
#define PI   3.14159265358979323846264338327950288419716939937510582097494
#define gconst  9.80665
 
/*------------------------------------------------------------------------*/
/* Frame 1                                                                */
/*------------------------------------------------------------------------*/
#define a1 0.0
#define alpha1 -PI/2.0
#define d1 0.0
/* theta1  */
/*---------------------------------------*/
#define theta1maxrad 2.6
#define theta1maxdeg 150.0
#define theta1minrad -2.6
#define theta1mindeg -150.0
/*------------------------------------------------------------------------*/
/* Frame 2                                                                */
/*------------------------------------------------------------------------*/
#define a2 0.0
#define alpha2 PI/2.0
#define d2 0.0
/* theta2  */
/*---------------------------------------*/
#define theta2maxrad 2.0
#define theta2maxdeg 113.0
#define theta2minrad -2.0
#define theta2mindeg -113.0
/*------------------------------------------------------------------------*/
/* Frame 3                                                                */
/*------------------------------------------------------------------------*/
#define a3 0.045
#define alpha3 -PI/2.0
#define d3 0.55
/* theta3  */
/*---------------------------------------*/
#define theta3maxrad 2.8
#define theta3maxdeg 157.0
#define theta3minrad -2.8
#define theta3mindeg -157.0
/*------------------------------------------------------------------------*/
/* Frame 4                                                                */
/*------------------------------------------------------------------------*/
#define a4 -0.045
#define alpha4 PI/2.0
#define d4 0.0
/* theta4  */
/*---------------------------------------*/
#define theta4maxrad 3.1
#define theta4maxdeg 180.0
#define theta4minrad -0.9
#define theta4mindeg -50.0
/*------------------------------------------------------------------------*/
/* Frame 5                                                                */
/*------------------------------------------------------------------------*/
#define a5 0.0
#define alpha5 -PI/2.0
#define d5 0.3
/* theta5  */
/*---------------------------------------*/
#define theta5maxrad 1.3
#define theta5maxdeg 75.0
#define theta5minrad -4.8
#define theta5mindeg -275.0
/*------------------------------------------------------------------------*/
/* Frame 6                                                                */
/*------------------------------------------------------------------------*/
#define a6 0.0
#define alpha6 PI/2.0
#define d6 0.0
/* theta6  */
/*---------------------------------------*/
#define theta6maxrad 1.6
#define theta6maxdeg 90.0
#define theta6minrad -1.6
#define theta6mindeg -90.0
/*------------------------------------------------------------------------*/
/* Frame 7                                                                */
/*------------------------------------------------------------------------*/
#define a7 0.0
#define alpha7 0.0
#define d7 0.06
/* theta7  */
/*---------------------------------------*/
#define theta7maxrad 2.2
#define theta7maxdeg 128.0
#define theta7minrad -2.2
#define theta7mindeg -128.0
/*------------------------------------------------------------------------*/
 
/*                                                                        */
/* Dynamics specification                                                 */
/*                                                                        */
 
/*------------------------------------------------------------------------*/
/* Link 1 Relative to Frame 1                                             */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 1 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 1 Relative to Frame 1 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix1[]={-0.0028e-6, -0.0294e-6, 0.9996e-6}*/
/* Iy1[]={-0.0778e-6, -0.9965e-6, -0.0295e-6}*/
/* Iz1[]={0.9970e-6, -0.0779e-6, 0.0006e-6}*/

/* Inertial constants due to motor rotor inertia */

#define J1motor 0.201
#define J2motor 0.182
#define J3motor 0.067
#define J4motor 0.034

/*
#define J1motor 0.0
#define J2motor 0.0
#define J3motor 0.0
#define J4motor 0.0
*/

#define Px1 59262.0287e-6
#define Py1 92041.6447e-6
#define Pz1 95176.7081e-6
/* Center of Mass (relative to frame 1) */
#define mass1 8.3936
#define comx1 0.3506e-3
#define comy1 132.6795e-3
#define comz1 0.6286e-3
/* Moments of Inertia (at center of mass, aligned with frame 1) */
#define Lxx1 95157.4294e-6
#define Lyx1 246.1404e-6
#define Lzx1 -95.0183e-6
#define Lxy1 246.1404e-6
#define Lyy1 (92032.3524e-6 + 0.0)
#define Lzy1 -962.6725e-6
#define Lxz1 -95.0183e-6
#define Lyz1 -962.6725e-6
#define Lzz1 59290.5997e-6
/* Moments of Inertia (at frame 1) */
#define Ixx1 242919.8516e-6
#define Iyx1 636.5542e-6
#define Izx1 -93.1687e-6
#define Ixy1 636.5542e-6
#define Iyy1 (92036.7003e-6 + J1motor)
#define Izy1 -262.6542e-6
#define Ixz1 -93.1687e-6
#define Iyz1 -262.6542e-6
#define Izz1 207050.7372e-6
/* General note: Mass does NOT include electrical or mechanical cables */
 
/*------------------------------------------------------------------------*/
/* Link 2 Relative to Frame 2                                             */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 2 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 2 Relative to Frame 2 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix2[]={-0.0105e-6, 0.8944e-6, 0.4472e-6}*/
/* Iy2[]={-0.0165e-6, -0.4473e-6, 0.8942e-6}*/
/* Iz2[]={0.9998e-6, 0.0020e-6, 0.0194e-6}*/
#define Px2 20106.7647e-6
#define Py2 23479.5484e-6
#define Pz2 29329.4065e-6
/* Center of Mass (relative to frame 2) */
#define mass2 4.8487
#define comx2 -0.2230e-3
#define comy2 -21.3924e-3
#define comz2 13.3754e-3
/* Moments of Inertia (at center of mass, aligned with frame 2) */
#define Lxx2 29326.8098e-6
#define Lyx2 -43.3994e-6
#define Lzx2 -129.2942e-6
#define Lxy2 -43.3994e-6
#define Lyy2 (20781.5826e-6 + 0.0)
#define Lzy2 1348.6924e-6
#define Lxz2 -129.2942e-6
#define Lyz2 1348.6924e-6
#define Lzz2 22807.3271e-6
/* Moments of Inertia (at frame 2) */
#define Ixx2 32413.1852e-6
#define Iyx2 -20.2663e-6
#define Izx2 -143.7579e-6
#define Ixy2 -20.2663e-6
#define Iyy2 (21649.2574e-6 + J2motor)
#define Izy2 -38.6737e-6
#define Ixz2 -143.7579e-6
#define Iyz2 -38.6737e-6
#define Izz2 25026.5101e-6
/* General note: Mass does NOT include electrical or mechanical cables */
 
/*------------------------------------------------------------------------*/
/* Link 3 Relative to Frame 3                                             */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 3 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 3 Relative to Frame 3 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix3[]={0.0433e-6, -0.9991e-6, 0.0003e-6}*/
/* Iy3[]={0.9855e-6, 0.0427e-6, 0.1641e-6}*/
/* Iz3[]={-0.1639e-6, -0.0068e-6, 0.9864e-6}*/
#define Px3 3057.4904e-6
#define Py3 56761.6071e-6
#define Pz3 56807.8528e-6
/* Center of Mass (relative to frame 3) */
#define mass3 1.7251
#define comx3 -38.7565e-3
#define comy3 217.9078e-3
#define comz3 0.0252e-3
/* Moments of Inertia (at center of mass, aligned with frame 3) */
#define Lxx3 56662.2970e-6
#define Lyx3 -2321.6892e-6
#define Lzx3 8.2125e-6
#define Lxy3 -2321.6892e-6
#define Lyy3 (3158.0509e-6 + 0.0)
#define Lzy3 -16.6307e-6
#define Lxz3 8.2125e-6
#define Lyz3 -16.6307e-6
#define Lzz3 56806.6024e-6
/* Moments of Inertia (at frame 3) */
#define Ixx3 138575.0448e-6
#define Iyx3 -16890.4832e-6
#define Izx3 6.5293e-6
#define Ixy3 -16890.4832e-6
#define Iyy3 (5749.2209e-6 + J3motor)
#define Izy3 -7.1669e-6
#define Ixz3 6.5293e-6
#define Iyz3 -7.1669e-6
#define Izz3 141310.5180e-6
/* General note: Mass does NOT include electrical or mechanical cables */
 
/*------------------------------------------------------------------------*/
/* Link 4 and Outer Link Relative to Frame 4                              */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 5 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 4 and Outer Link Relative to Frame 4 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix4[]={-0.1005e-6, 0.0010e-6, 0.9949e-6}*/
/* Iy4[]={0.9949e-6, 0.0036e-6, 0.1005e-6}*/
/* Iz4[]={-0.0035e-6, 1.0000e-6, -0.0014e-6}*/
#define Px4 1852.9293e-6
#define Py4 19064.6829e-6
#define Pz4 19340.6186e-6
/* Center of Mass (relative to frame 4) */
//#define mass4 (2.0824 - 0.419)
#define mass4 2.0824
#define comx4 6.2895e-3
#define comy4 -0.0010e-3
#define comz4 111.0633e-3

/* Moments of Inertia (at center of mass, aligned with frame 4) */
#define Lxx4 10065.3990e-6
#define Lyx4 14.6007e-6
#define Lzx4 -1392.4965e-6
#define Lxy4 14.6007e-6
#define Lyy4 10000.5377e-6
#define Lzy4 29.4814e-6
#define Lxz4 -1392.4965e-6
#define Lyz4 29.4814e-6
#define Lzz4 2838.9554e-6

/* Moments of Inertia (at frame 4) */
#define Ixx4 35752.4193E-6
#define Iyx4 14.5876E-6
#define Izx4 62.1491E-6
#define Ixy4 14.5876E-6
#define Iyy4 35769.9341E-6
#define Izy4 29.2508E-6
#define Ixz4 62.1491E-6
#define Iyz4 29.2508E-6
#define Izz4 2921.3314E-6


/* General note: Mass does NOT include electrical or mechanical cables */
 
/*------------------------------------------------------------------------*/
/* Link 5 Relative to Frame 5                                             */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 7 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 5 Relative to Frame 5 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix5[]={-0.0004e-6, 0.9999e-6, -0.0139e-6}*/
/* Iy5[]={1.0000e-6, 0.0004e-6, -0.0003e-6}*/
/* Iz5[]={-0.0003e-6, -0.0139e-6, -0.9999e-6}*/
#define Px5 172.3294e-6
#define Py5 321.0142e-6
#define Pz5 350.7125e-6
/* Center of Mass (relative to frame 5) */
#define mass5 0.3067
#define comx5 0.0584e-3
#define comy5 28.3754e-3
#define comz5 0.1902e-3
/* Moments of Inertia (at center of mass, aligned with frame 5) */
#define Lxx5 321.0141e-6
#define Lyx5 -0.0667e-6
#define Lzx5 -0.0079e-6
#define Lxy5 -0.0667e-6
#define Lyy5 172.3637e-6
#define Lzy5 -2.4724e-6
#define Lxz5 -0.0079e-6
#define Lyz5 -2.4724e-6
#define Lzz5 350.6782e-6
/* Moments of Inertia (at frame 5) */
#define Ixx5 567.9724e-6
#define Iyx5 0.4416e-6
#define Izx5 -0.0045e-6
#define Ixy5 0.4416e-6
#define Iyy5 172.3759e-6
#define Izy5 -0.8172e-6
#define Ixz5 -0.0045e-6
#define Iyz5 -0.8172e-6
#define Izz5 597.6265e-6
/* General note: Mass does NOT include electrical or mechanical cables */
 
/*------------------------------------------------------------------------*/
/* Link 6 Relative to Frame 6                                             */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 8 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 6 Relative to Frame 6 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix6[]={-0.0004e-6, -0.9712e-6, 0.2384e-6}*/
/* Iy6[]={0.0020e-6, -0.2384e-6, -0.9712e-6}*/
/* Iz6[]={1.0000e-6, 0.0001e-6, 0.0021e-6}*/
#define Px6 253.9995e-6
#define Py6 523.2057e-6
#define Pz6 604.1925e-6
/* Center of Mass (relative to frame 6) */
#define mass6 0.4278
#define comx6 -0.0311e-3
#define comy6 -14.8635e-3
#define comz6 25.6326e-3
/* Moments of Inertia (at center of mass, aligned with frame 6) */
#define Lxx6 604.1921e-6
#define Lyx6 0.0825e-6
#define Lzx6 -0.1896e-6
#define Lxy6 0.0825e-6
#define Lyy6 269.3020e-6
#define Lzy6 -62.3326e-6
#define Lxz6 -0.1896e-6
#define Lyz6 -62.3326e-6
#define Lzz6 507.9036e-6
/* Moments of Inertia (at frame 6) */
#define Ixx6 979.8079e-6
#define Iyx6 0.2804e-6
#define Izx6 -0.5308e-6
#define Ixy6 0.2804e-6
#define Iyy6 550.3998e-6
#define Izy6 -225.3322e-6
#define Ixz6 -0.5308e-6
#define Iyz6 -225.3322e-6
#define Izz6 602.4224e-6
/* General note: Mass does NOT include electrical or mechanical cables */
 
/*------------------------------------------------------------------------*/
/* Link 7 Relative to Frame 7                                             */
/*------------------------------------------------------------------------*/
/*  2006 Barrett Technology, Inc. WAMArm & Wrist – Inertial Specifications Page 9 of 9 */
/* Document: D1005, Version: AB.00 */
/* Link 7 Relative to Frame 7 */
/* Principal Axes and Moments of Inertia (at center of mass) */
/* Ix7[]={1.0000e-6, -0.0004e-6, 0.0000e-6}*/
/* Iy7[]={0.0004e-6, 1.0000e-6, 0.0002e-6}*/
/* Iz7[]={0.0000e-6, -0.0002e-6, 1.0000e-6}*/
#define Px7 21.4102e-6
#define Py7 21.6157e-6
#define Pz7 42.1975e-6
/* Center of Mass (relative to frame 7) */
#define mass7 0.0557
#define comx7 -0.0001e-3
#define comy7 -0.1823e-3
#define comz7 -284.7431e-3
#define toolx7 0.0
#define tooly7 0.0
#define toolz7 0.0
/* Moments of Inertia (at center of mass, aligned with frame 7) */
#define Ixx7 4536.8120e-6
#define Iyx7 -0.0001e-6
#define Izx7 0.0011e-6
#define Ixy7 -0.0001e-6
#define Iyy7 4537.0156e-6
#define Izy7 2.8944e-6
#define Ixz7 0.0011e-6
#define Iyz7 2.8944e-6
#define Izz7 42.1994e-6
/* Moments of Inertia (at frame 7) */
#define Lxx7 21.4102e-6
#define Lyx7 -0.0001e-6
#define Lzx7 0.0000e-6
#define Lxy7 -0.0001e-6
#define Lyy7 21.6157e-6
#define Lzy7 0.0040e-6
#define Lxz7 0.0000e-6
#define Lyz7 0.0040e-6
#define Lzz7 42.1975e-6
/* General note: Mass does NOT include electrical or mechanical cables */
 
